<?php

namespace Drupal\search_api_vragen_ai\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure settings for 'vragen.ai' integration.
 */
class VragenAiSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'search_api_vragen_ai_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['search_api_vragen_ai.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $vragen_ai_settings = $this->config('search_api_vragen_ai.settings');

    $form['endpoint'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Endpoint'),
      '#description' => $this->t('Endpoint URL for Vragen.ai. More information on <a href="https://www.vragen.ai/">Vragen.ai</a>.'),
      '#default_value' => $vragen_ai_settings->get('vragen_ai_endpoint') ?? '',
      '#required' => TRUE,
    ];

    $form['token'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Bearer token'),
      '#description' => $this->t('Enables access to the Vragen.ai API. More information on <a href="https://www.vragen.ai/">Vragen.ai</a>'),
      '#default_value' => $vragen_ai_settings->get('vragen_ai_token') ?? '',
      '#required' => TRUE,
    ];

    $form['actions'] = [
      '#type' => 'actions',
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
      '#button_type' => 'primary',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $config = $this->config('search_api_vragen_ai.settings')
      ->set('vragen_ai_endpoint', $form_state->getValue('endpoint'))
      ->set('vragen_ai_token', $form_state->getValue('token'));
    $config->save();
    $this->messenger()->addMessage($this->t('The configuration options have been saved.'));
    parent::submitForm($form, $form_state);
  }

}
